==> blesta-5.10.2.zip: blesta/components/modules/solusvm/language/sv_se/solusvm.php <==
<?php
/**
 * Solusvm
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Solusvm.tab_client_ips.cancel'] = 'Avbryt';
$lang['Solusvm.tab_client_ips.remove_ip'] = 'Ta bort IP';
$lang['Solusvm.tab_client_ips.confirm_remove_ip'] = 'Är du säker på att du vill ta bort denna IP-adress permanent?';
$lang['Solusvm.tab_client_ips.heading_remove_ip'] = 'Ta bort IP %1$s';
$lang['Solusvm.tab_client_ips.primary_ip'] = 'Primär IP-adress';
$lang['Solusvm.tab_client_ips.heading_extra'] = 'Extra IP-adresser';
$lang['Solusvm.tab_ips.confirm_remove'] = 'Är du säker på att du vill ta bort den här IP-adressen permanent?';
$lang['Solusvm.tab_ips.option_remove'] = 'Ta bort IP';
$lang['Solusvm.tab_ips.heading_options'] = 'Alternativ';
$lang['Solusvm.tab_ips.heading_ip'] = 'IP-adress';
$lang['Solusvm.tab_ips.heading_extra_ips'] = 'Extra IP-adresser';
$lang['Solusvm.tab_ips.primary_ip'] = 'Primär IP-adress: %1$s';
$lang['Solusvm.tab_ips.heading_ips'] = 'IP-adresser';
$lang['Solusvm.tab_client_console.vnc_password'] = 'Lösenord för VNC';
$lang['Solusvm.tab_client_console.console_password'] = 'Lösenord för konsol';
$lang['Solusvm.tab_client_console.console_username'] = 'Användarnamn för konsol';
$lang['Solusvm.tab_client_console.heading_console'] = 'Konsol';
$lang['Solusvm.tab_console.vnc_password'] = 'Lösenord för VNC:';
$lang['Solusvm.tab_console.vnc_port'] = 'VNC-port:';
$lang['Solusvm.tab_console.vnc_ip'] = 'VNC-värd:';
$lang['Solusvm.tab_console.console_password'] = 'Lösenord för konsol:';
$lang['Solusvm.tab_console.console_username'] = 'Användarnamn för konsol:';
$lang['Solusvm.tab_console.heading_console'] = 'Konsol';
$lang['Solusvm.tab_client_stats.heading_graphs'] = 'Grafer';
$lang['Solusvm.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Solusvm.tab_client_stats.space'] = 'Diskutrymme';
$lang['Solusvm.tab_client_stats.memory'] = 'Minne';
$lang['Solusvm.tab_client_stats.bandwidth'] = 'Bandbredd';
$lang['Solusvm.tab_client_stats.heading_stats'] = 'Statistik';
$lang['Solusvm.tab_stats.heading_graphs'] = 'Grafer';
$lang['Solusvm.tab_status.no_results'] = 'Statistik är för närvarande inte tillgänglig.';
$lang['Solusvm.tab_stats.space_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.space_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.space'] = 'Diskutrymme:';
$lang['Solusvm.tab_stats.memory_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.memory_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.memory'] = 'Minne:';
$lang['Solusvm.tab_stats.bandwidth_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.bandwidth_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.bandwidth'] = 'Bandbredd:';
$lang['Solusvm.tab_stats.heading_stats'] = 'Statistik';
$lang['Solusvm.tab_client_actions.text_generate_password'] = 'Skapa lösenord';
$lang['Solusvm.tab_client_actions.field_password_submit'] = 'Ändra lösenord';
$lang['Solusvm.tab_client_actions.field_confirm_password'] = 'Bekräfta lösenord';
$lang['Solusvm.tab_client_actions.field_password'] = 'Nytt lösenord för roten';
$lang['Solusvm.tab_client_actions.heading_password'] = 'Ändra lösenord';
$lang['Solusvm.tab_client_actions.field_hostname_submit'] = 'Ändra värdnamn';
$lang['Solusvm.tab_client_actions.field_hostname'] = 'Värdnamn';
$lang['Solusvm.tab_client_actions.text_hostname_reboot'] = 'En ändring av värdnamnet träder i kraft först när servern har startats om.';
$lang['Solusvm.tab_client_actions.heading_hostname'] = 'Ändra värdnamn';
$lang['Solusvm.tab_client_actions.field_reinstall_submit'] = 'Installera om';
$lang['Solusvm.tab_client_actions.field_confirm'] = 'Jag förstår att ominstallationen innebär att alla data på servern raderas permanent och att den valda mallen installeras.';
$lang['Solusvm.tab_client_actions.field_template'] = 'Mall';
$lang['Solusvm.tab_client_actions.heading_reinstall'] = 'Installera om';
$lang['Solusvm.tab_client_actions.status_disabled'] = 'Inaktiverad';
$lang['Solusvm.tab_client_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_client_actions.status_online'] = 'Online';
$lang['Solusvm.tab_client_actions.heading_node'] = 'Nod';
$lang['Solusvm.tab_client_actions.heading_server_status'] = 'Serverstatus';
$lang['Solusvm.tab_client_actions.heading_actions'] = 'Åtgärder';
$lang['Solusvm.tab_actions.text_generate_password'] = 'Skapa lösenord';
$lang['Solusvm.tab_actions.field_password_submit'] = 'Ändra lösenord';
$lang['Solusvm.tab_actions.field_confirm_password'] = 'Bekräfta lösenord';
$lang['Solusvm.tab_actions.field_password'] = 'Nytt lösenord för roten';
$lang['Solusvm.tab_actions.heading_password'] = 'Ändra lösenord';
$lang['Solusvm.tab_actions.field_hostname_submit'] = 'Ändra värdnamn';
$lang['Solusvm.tab_actions.field_hostname'] = 'Värdnamn';
$lang['Solusvm.tab_actions.text_hostname_reboot'] = 'En ändring av värdnamnet träder i kraft först när servern har startats om.';
$lang['Solusvm.tab_actions.heading_hostname'] = 'Ändra värdnamn';
$lang['Solusvm.tab_actions.field_reinstall_submit'] = 'Installera om';
$lang['Solusvm.tab_actions.field_confirm'] = 'Jag förstår att ominstallationen innebär att alla data på servern raderas permanent och att den valda mallen installeras.';
$lang['Solusvm.tab_actions.field_template'] = 'Mall';
$lang['Solusvm.tab_actions.heading_reinstall'] = 'Installera om';
$lang['Solusvm.tab_actions.node'] = 'Nod: %1$s';
$lang['Solusvm.tab_actions.server_status'] = 'Serverstatus';
$lang['Solusvm.tab_actions.status_disabled'] = 'Inaktiverad';
$lang['Solusvm.tab_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_actions.status_online'] = 'Online';
$lang['Solusvm.tab_actions.heading_actions'] = 'Åtgärder';
$lang['Solusvm.tab_ips'] = 'IP-adresser';
$lang['Solusvm.tab_console'] = 'Konsol';
$lang['Solusvm.tab_stats'] = 'Statistik';
$lang['Solusvm.tab_actions'] = 'Serveråtgärder';
$lang['Solusvm.service_info.solusvm_main_ip_address'] = 'Primär IP-adress';
$lang['Solusvm.service_field.tooltip.solusvm_vserver_id'] = 'Virtual Server ID anger den VPS från SolusVM som den här tjänsten ska kopplas till. Om du ändrar det här värdet påverkas tjänsten endast lokalt.';
$lang['Solusvm.service_field.solusvm_vserver_id'] = 'ID för virtuell server';
$lang['Solusvm.service_field.solusvm_template'] = 'Mall';
$lang['Solusvm.service_field.solusvm_hostname'] = 'Värdnamn';
$lang['Solusvm.package_fields.node_group'] = 'Nodgrupp';
$lang['Solusvm.package_fields.set_node_group'] = 'Tilldela en nodgrupp';
$lang['Solusvm.package_fields.set_node'] = 'Tilldela en uppsättning noder';
$lang['Solusvm.package_fields.available_nodes'] = 'Tillgängliga noder';
$lang['Solusvm.package_fields.assigned_nodes'] = 'Tilldelade noder';
$lang['Solusvm.package_fields.plan'] = 'Planera';
$lang['Solusvm.package_fields.client_set_template'] = 'Låt kunden sätta mallen';
$lang['Solusvm.package_fields.admin_set_template'] = 'Välj en mall';
$lang['Solusvm.package_fields.template'] = 'Mall';
$lang['Solusvm.package_fields.type'] = 'Typ';
$lang['Solusvm.package_fields.tooltip.total_base_ip_addresses'] = 'Ange det totala antalet IP-adresser som ska ingå i nya tjänster. Det måste finnas minst en, och IP-adresserna kan inte tas bort.';
$lang['Solusvm.package_fields.total_base_ip_addresses'] = 'Bas IP-adress Antal';
$lang['Solusvm.edit_row.add_btn'] = 'Uppdatera server';
$lang['Solusvm.edit_row.basic_title'] = 'Grundläggande inställningar';
$lang['Solusvm.edit_row.box_title'] = 'Redigera SolusVM Server';
$lang['Solusvm.add_row.add_btn'] = 'Lägg till server';
$lang['Solusvm.add_row.basic_title'] = 'Grundläggande inställningar';
$lang['Solusvm.add_row.box_title'] = 'Lägg till SolusVM-server';
$lang['Solusvm.types.kvm'] = 'KVM';
$lang['Solusvm.types.xen_hvm'] = 'Xen HVM';
$lang['Solusvm.types.xen'] = 'Xen';
$lang['Solusvm.types.openvz'] = 'OpenVZ';
$lang['Solusvm.row_meta.default_port'] = '5656';
$lang['Solusvm.row_meta.port'] = 'SSL-portnummer';
$lang['Solusvm.row_meta.host'] = 'Värdnamn';
$lang['Solusvm.row_meta.key'] = 'Nyckel';
$lang['Solusvm.row_meta.user_id'] = 'Användar-ID';
$lang['Solusvm.row_meta.server_name'] = 'Server Etikett';
$lang['Solusvm.order_options.first'] = 'Första icke-fullständiga servern';
$lang['Solusvm.manage.module_groups_no_results'] = 'Det finns inga servergrupper.';
$lang['Solusvm.manage.module_rows_no_results'] = 'Det finns inga servrar.';
$lang['Solusvm.manage.module_groups.confirm_delete'] = 'Är du säker på att du vill ta bort den här servergruppen?';
$lang['Solusvm.manage.module_rows.confirm_delete'] = 'Är du säker på att du vill ta bort den här servern?';
$lang['Solusvm.manage.module_groups.delete'] = 'Radera';
$lang['Solusvm.manage.module_rows.delete'] = 'Radera';
$lang['Solusvm.manage.module_groups.edit'] = 'Redigera';
$lang['Solusvm.manage.module_rows.edit'] = 'Redigera';
$lang['Solusvm.manage.module_groups_heading.options'] = 'Alternativ';
$lang['Solusvm.manage.module_groups_heading.servers'] = 'Antal servrar';
$lang['Solusvm.manage.module_groups_heading.name'] = 'Gruppens namn';
$lang['Solusvm.manage.module_rows_heading.options'] = 'Alternativ';
$lang['Solusvm.manage.module_rows_heading.host'] = 'Värdnamn';
$lang['Solusvm.manage.module_rows_heading.server_label'] = 'Server Etikett';
$lang['Solusvm.manage.module_groups_title'] = 'SolusVM Master Server-grupper';
$lang['Solusvm.manage.module_rows_title'] = 'SolusVM-masterservrar';
$lang['Solusvm.add_module_group'] = 'Lägg till servergrupp';
$lang['Solusvm.add_module_row'] = 'Lägg till server';
$lang['Solusvm.module_group'] = 'SolusVM huvudgrupp';
$lang['Solusvm.module_row_plural'] = 'Servrar';
$lang['Solusvm.module_row'] = 'SolusVM Master Server';
$lang['Solusvm.description'] = 'Solus Virtual Manager (SolusVM) är ett kraftfullt GUI-baserat VPS-hanteringssystem med fullt stöd för OpenVZ, Linux KVM, Xen Paravirtualization och Xen HVM.';
$lang['Solusvm.name'] = 'SolusVM';
$lang['Solusvm.!percent.used'] = '%1$s%';
$lang['Solusvm.!bytes.value'] = '%1$s%2$s';
$lang['Solusvm.please_select'] = '-- Vänligen välj --';
$lang['Solusvm.!success.reinstall'] = 'Servern håller nu på att installeras om.';
$lang['Solusvm.!success.hostname'] = 'Värdnamnet ändrades framgångsrikt.';
$lang['Solusvm.!success.password'] = 'Lösenordet ändrades framgångsrikt.';
$lang['Solusvm.!success.shutdown'] = 'Servern håller nu på att stängas ner.';
$lang['Solusvm.!success.reboot'] = 'Servern håller nu på att startas om.';
$lang['Solusvm.!success.boot'] = 'Servern håller nu på att startas.';
$lang['Solusvm.!error.configoptions[customextraip].valid'] = 'Antalet extra IP-adresser får inte minskas utan att det anges vilka IP-adresser som skall tas bort.';
$lang['Solusvm.!error.solusvm_vserver_id.format'] = 'ID för virtuell server måste vara ett heltal.';
$lang['Solusvm.!error.solusvm_root_password.matches'] = 'Lösenorden för root stämmer inte överens.';
$lang['Solusvm.!error.solusvm_root_password.length'] = 'Rotlösenordet måste vara minst 6 tecken långt.';
$lang['Solusvm.!error.api.confirm.valid'] = 'Du måste bekräfta att du förstår ominstallationsåtgärden för att kunna utföra ominstallationen av mallen.';
$lang['Solusvm.!error.api.template.valid'] = 'Den valda mallen är ogiltig.';
$lang['Solusvm.!error.create_client.failed'] = 'Ett internt fel uppstod och klientkontot kunde inte skapas.';
$lang['Solusvm.!error.solusvm_template.valid'] = 'Välj en giltig mall.';
$lang['Solusvm.!error.solusvm_hostname.format'] = 'Ange ett giltigt fullt kvalificerat domännamn (t.ex. host.domain.com) för värdnamnet.';
$lang['Solusvm.!error.api.internal'] = 'Ett internt fel uppstod, eller så svarade inte servern på begäran.';
$lang['Solusvm.!error.meta[total_base_ip_addresses].format'] = 'Ange endast siffror för IP-adressen, med ett värde på 1 eller mer.';
$lang['Solusvm.!error.meta[template].empty'] = 'Vänligen välj en mall.';
$lang['Solusvm.!error.meta[set_template].format'] = 'Ange om en mall ska väljas eller om kunden själv ska få ange en mall.';
$lang['Solusvm.!error.meta[plan].empty'] = 'Vänligen välj en plan.';
$lang['Solusvm.!error.meta[nodes].empty'] = 'Välj minst en nod eller nodgrupp.';
$lang['Solusvm.!error.meta[type].valid'] = 'Välj en giltig virtualiseringstyp.';
$lang['Solusvm.!error.port.format'] = 'Ange ett giltigt portnummer.';
$lang['Solusvm.!error.host.format'] = 'Värdnamnet verkar vara ogiltigt.';
$lang['Solusvm.!error.key.empty'] = 'Vänligen ange en nyckel.';
$lang['Solusvm.!error.user_id.empty'] = 'Ange ett användar-ID.';
$lang['Solusvm.!error.server_name.empty'] = 'Vänligen ange en serveretikett.';
$lang['SolusVM.!error.simplexml_required'] = 'Tillägget simplexml krävs för denna modul.';
$lang['Solusvm.!actions.password'] = 'Ändra lösenord';
$lang['Solusvm.!actions.hostname'] = 'Ändra värdnamn';
$lang['Solusvm.!actions.reinstall'] = 'Installera om';
$lang['Solusvm.!actions.shutdown'] = 'Avstängning';
$lang['Solusvm.!actions.reboot'] = 'Omstart';
$lang['Solusvm.!actions.boot'] = 'Boot';

==> blesta-5.11.4.zip: blesta/components/modules/solusvm/language/sv_se/solusvm.php <==
<?php
/**
 * Solusvm
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Solusvm.tab_client_ips.cancel'] = 'Avbryt';
$lang['Solusvm.tab_client_ips.remove_ip'] = 'Ta bort IP';
$lang['Solusvm.tab_client_ips.confirm_remove_ip'] = 'Är du säker på att du vill ta bort denna IP-adress permanent?';
$lang['Solusvm.tab_client_ips.heading_remove_ip'] = 'Ta bort IP %1$s';
$lang['Solusvm.tab_client_ips.primary_ip'] = 'Primär IP-adress';
$lang['Solusvm.tab_client_ips.heading_extra'] = 'Extra IP-adresser';
$lang['Solusvm.tab_ips.confirm_remove'] = 'Är du säker på att du vill ta bort den här IP-adressen permanent?';
$lang['Solusvm.tab_ips.option_remove'] = 'Ta bort IP';
$lang['Solusvm.tab_ips.heading_options'] = 'Alternativ';
$lang['Solusvm.tab_ips.heading_ip'] = 'IP-adress';
$lang['Solusvm.tab_ips.heading_extra_ips'] = 'Extra IP-adresser';
$lang['Solusvm.tab_ips.primary_ip'] = 'Primär IP-adress: %1$s';
$lang['Solusvm.tab_ips.heading_ips'] = 'IP-adresser';
$lang['Solusvm.tab_client_console.vnc_password'] = 'Lösenord för VNC';
$lang['Solusvm.tab_client_console.console_password'] = 'Lösenord för konsol';
$lang['Solusvm.tab_client_console.console_username'] = 'Användarnamn för konsol';
$lang['Solusvm.tab_client_console.heading_console'] = 'Konsol';
$lang['Solusvm.tab_console.vnc_password'] = 'Lösenord för VNC:';
$lang['Solusvm.tab_console.vnc_port'] = 'VNC-port:';
$lang['Solusvm.tab_console.vnc_ip'] = 'VNC-värd:';
$lang['Solusvm.tab_console.console_password'] = 'Lösenord för konsol:';
$lang['Solusvm.tab_console.console_username'] = 'Användarnamn för konsol:';
$lang['Solusvm.tab_console.heading_console'] = 'Konsol';
$lang['Solusvm.tab_client_stats.heading_graphs'] = 'Grafer';
$lang['Solusvm.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Solusvm.tab_client_stats.space'] = 'Diskutrymme';
$lang['Solusvm.tab_client_stats.memory'] = 'Minne';
$lang['Solusvm.tab_client_stats.bandwidth'] = 'Bandbredd';
$lang['Solusvm.tab_client_stats.heading_stats'] = 'Statistik';
$lang['Solusvm.tab_stats.heading_graphs'] = 'Grafer';
$lang['Solusvm.tab_status.no_results'] = 'Statistik är för närvarande inte tillgänglig.';
$lang['Solusvm.tab_stats.space_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.space_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.space'] = 'Diskutrymme:';
$lang['Solusvm.tab_stats.memory_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.memory_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.memory'] = 'Minne:';
$lang['Solusvm.tab_stats.bandwidth_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.bandwidth_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.bandwidth'] = 'Bandbredd:';
$lang['Solusvm.tab_stats.heading_stats'] = 'Statistik';
$lang['Solusvm.tab_client_actions.text_generate_password'] = 'Skapa lösenord';
$lang['Solusvm.tab_client_actions.field_password_submit'] = 'Ändra lösenord';
$lang['Solusvm.tab_client_actions.field_confirm_password'] = 'Bekräfta lösenord';
$lang['Solusvm.tab_client_actions.field_password'] = 'Nytt lösenord för roten';
$lang['Solusvm.tab_client_actions.heading_password'] = 'Ändra lösenord';
$lang['Solusvm.tab_client_actions.field_hostname_submit'] = 'Ändra värdnamn';
$lang['Solusvm.tab_client_actions.field_hostname'] = 'Värdnamn';
$lang['Solusvm.tab_client_actions.text_hostname_reboot'] = 'En ändring av värdnamnet träder i kraft först när servern har startats om.';
$lang['Solusvm.tab_client_actions.heading_hostname'] = 'Ändra värdnamn';
$lang['Solusvm.tab_client_actions.field_reinstall_submit'] = 'Installera om';
$lang['Solusvm.tab_client_actions.field_confirm'] = 'Jag förstår att ominstallationen innebär att alla data på servern raderas permanent och att den valda mallen installeras.';
$lang['Solusvm.tab_client_actions.field_template'] = 'Mall';
$lang['Solusvm.tab_client_actions.heading_reinstall'] = 'Installera om';
$lang['Solusvm.tab_client_actions.status_disabled'] = 'Inaktiverad';
$lang['Solusvm.tab_client_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_client_actions.status_online'] = 'Online';
$lang['Solusvm.tab_client_actions.heading_node'] = 'Nod';
$lang['Solusvm.tab_client_actions.heading_server_status'] = 'Serverstatus';
$lang['Solusvm.tab_client_actions.heading_actions'] = 'Åtgärder';
$lang['Solusvm.tab_actions.text_generate_password'] = 'Skapa lösenord';
$lang['Solusvm.tab_actions.field_password_submit'] = 'Ändra lösenord';
$lang['Solusvm.tab_actions.field_confirm_password'] = 'Bekräfta lösenord';
$lang['Solusvm.tab_actions.field_password'] = 'Nytt lösenord för roten';
$lang['Solusvm.tab_actions.heading_password'] = 'Ändra lösenord';
$lang['Solusvm.tab_actions.field_hostname_submit'] = 'Ändra värdnamn';
$lang['Solusvm.tab_actions.field_hostname'] = 'Värdnamn';
$lang['Solusvm.tab_actions.text_hostname_reboot'] = 'En ändring av värdnamnet träder i kraft först när servern har startats om.';
$lang['Solusvm.tab_actions.heading_hostname'] = 'Ändra värdnamn';
$lang['Solusvm.tab_actions.field_reinstall_submit'] = 'Installera om';
$lang['Solusvm.tab_actions.field_confirm'] = 'Jag förstår att ominstallationen innebär att alla data på servern raderas permanent och att den valda mallen installeras.';
$lang['Solusvm.tab_actions.field_template'] = 'Mall';
$lang['Solusvm.tab_actions.heading_reinstall'] = 'Installera om';
$lang['Solusvm.tab_actions.node'] = 'Nod: %1$s';
$lang['Solusvm.tab_actions.server_status'] = 'Serverstatus';
$lang['Solusvm.tab_actions.status_disabled'] = 'Inaktiverad';
$lang['Solusvm.tab_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_actions.status_online'] = 'Online';
$lang['Solusvm.tab_actions.heading_actions'] = 'Åtgärder';
$lang['Solusvm.tab_ips'] = 'IP-adresser';
$lang['Solusvm.tab_console'] = 'Konsol';
$lang['Solusvm.tab_stats'] = 'Statistik';
$lang['Solusvm.tab_actions'] = 'Serveråtgärder';
$lang['Solusvm.service_info.solusvm_main_ip_address'] = 'Primär IP-adress';
$lang['Solusvm.service_field.tooltip.solusvm_vserver_id'] = 'Virtual Server ID anger den VPS från SolusVM som den här tjänsten ska kopplas till. Om du ändrar det här värdet påverkas tjänsten endast lokalt.';
$lang['Solusvm.service_field.solusvm_vserver_id'] = 'ID för virtuell server';
$lang['Solusvm.service_field.solusvm_template'] = 'Mall';
$lang['Solusvm.service_field.solusvm_hostname'] = 'Värdnamn';
$lang['Solusvm.package_fields.node_group'] = 'Nodgrupp';
$lang['Solusvm.package_fields.set_node_group'] = 'Tilldela en nodgrupp';
$lang['Solusvm.package_fields.set_node'] = 'Tilldela en uppsättning noder';
$lang['Solusvm.package_fields.available_nodes'] = 'Tillgängliga noder';
$lang['Solusvm.package_fields.assigned_nodes'] = 'Tilldelade noder';
$lang['Solusvm.package_fields.plan'] = 'Planera';
$lang['Solusvm.package_fields.client_set_template'] = 'Låt kunden sätta mallen';
$lang['Solusvm.package_fields.admin_set_template'] = 'Välj en mall';
$lang['Solusvm.package_fields.template'] = 'Mall';
$lang['Solusvm.package_fields.type'] = 'Typ';
$lang['Solusvm.package_fields.tooltip.total_base_ip_addresses'] = 'Ange det totala antalet IP-adresser som ska ingå i nya tjänster. Det måste finnas minst en, och IP-adresserna kan inte tas bort.';
$lang['Solusvm.package_fields.total_base_ip_addresses'] = 'Bas IP-adress Antal';
$lang['Solusvm.edit_row.add_btn'] = 'Uppdatera server';
$lang['Solusvm.edit_row.basic_title'] = 'Grundläggande inställningar';
$lang['Solusvm.edit_row.box_title'] = 'Redigera SolusVM Server';
$lang['Solusvm.add_row.add_btn'] = 'Lägg till server';
$lang['Solusvm.add_row.basic_title'] = 'Grundläggande inställningar';
$lang['Solusvm.add_row.box_title'] = 'Lägg till SolusVM-server';
$lang['Solusvm.types.kvm'] = 'KVM';
$lang['Solusvm.types.xen_hvm'] = 'Xen HVM';
$lang['Solusvm.types.xen'] = 'Xen';
$lang['Solusvm.types.openvz'] = 'OpenVZ';
$lang['Solusvm.row_meta.default_port'] = '5656';
$lang['Solusvm.row_meta.port'] = 'SSL-portnummer';
$lang['Solusvm.row_meta.host'] = 'Värdnamn';
$lang['Solusvm.row_meta.key'] = 'Nyckel';
$lang['Solusvm.row_meta.user_id'] = 'Användar-ID';
$lang['Solusvm.row_meta.server_name'] = 'Server Etikett';
$lang['Solusvm.order_options.first'] = 'Första icke-fullständiga servern';
$lang['Solusvm.manage.module_groups_no_results'] = 'Det finns inga servergrupper.';
$lang['Solusvm.manage.module_rows_no_results'] = 'Det finns inga servrar.';
$lang['Solusvm.manage.module_groups.confirm_delete'] = 'Är du säker på att du vill ta bort den här servergruppen?';
$lang['Solusvm.manage.module_rows.confirm_delete'] = 'Är du säker på att du vill ta bort den här servern?';
$lang['Solusvm.manage.module_groups.delete'] = 'Radera';
$lang['Solusvm.manage.module_rows.delete'] = 'Radera';
$lang['Solusvm.manage.module_groups.edit'] = 'Redigera';
$lang['Solusvm.manage.module_rows.edit'] = 'Redigera';
$lang['Solusvm.manage.module_groups_heading.options'] = 'Alternativ';
$lang['Solusvm.manage.module_groups_heading.servers'] = 'Antal servrar';
$lang['Solusvm.manage.module_groups_heading.name'] = 'Gruppens namn';
$lang['Solusvm.manage.module_rows_heading.options'] = 'Alternativ';
$lang['Solusvm.manage.module_rows_heading.host'] = 'Värdnamn';
$lang['Solusvm.manage.module_rows_heading.server_label'] = 'Server Etikett';
$lang['Solusvm.manage.module_groups_title'] = 'SolusVM Master Server-grupper';
$lang['Solusvm.manage.module_rows_title'] = 'SolusVM-masterservrar';
$lang['Solusvm.add_module_group'] = 'Lägg till servergrupp';
$lang['Solusvm.add_module_row'] = 'Lägg till server';
$lang['Solusvm.module_group'] = 'SolusVM huvudgrupp';
$lang['Solusvm.module_row_plural'] = 'Servrar';
$lang['Solusvm.module_row'] = 'SolusVM Master Server';
$lang['Solusvm.description'] = 'Solus Virtual Manager (SolusVM) är ett kraftfullt GUI-baserat VPS-hanteringssystem med fullt stöd för OpenVZ, Linux KVM, Xen Paravirtualization och Xen HVM.';
$lang['Solusvm.name'] = 'SolusVM';
$lang['Solusvm.!percent.used'] = '%1$s';
$lang['Solusvm.!bytes.value'] = '%1$s%2$s';
$lang['Solusvm.please_select'] = '-- Vänligen välj --';
$lang['Solusvm.!success.reinstall'] = 'Servern håller nu på att installeras om.';
$lang['Solusvm.!success.hostname'] = 'Värdnamnet ändrades framgångsrikt.';
$lang['Solusvm.!success.password'] = 'Lösenordet ändrades framgångsrikt.';
$lang['Solusvm.!success.shutdown'] = 'Servern håller nu på att stängas ner.';
$lang['Solusvm.!success.reboot'] = 'Servern håller nu på att startas om.';
$lang['Solusvm.!success.boot'] = 'Servern håller nu på att startas.';
$lang['Solusvm.!error.configoptions[customextraip].valid'] = 'Antalet extra IP-adresser får inte minskas utan att det anges vilka IP-adresser som skall tas bort.';
$lang['Solusvm.!error.solusvm_vserver_id.format'] = 'ID för virtuell server måste vara ett heltal.';
$lang['Solusvm.!error.solusvm_root_password.matches'] = 'Lösenorden för root stämmer inte överens.';
$lang['Solusvm.!error.solusvm_root_password.length'] = 'Rotlösenordet måste vara minst 6 tecken långt.';
$lang['Solusvm.!error.api.confirm.valid'] = 'Du måste bekräfta att du förstår ominstallationsåtgärden för att kunna utföra ominstallationen av mallen.';
$lang['Solusvm.!error.api.template.valid'] = 'Den valda mallen är ogiltig.';
$lang['Solusvm.!error.create_client.failed'] = 'Ett internt fel uppstod och klientkontot kunde inte skapas.';
$lang['Solusvm.!error.solusvm_template.valid'] = 'Välj en giltig mall.';
$lang['Solusvm.!error.solusvm_hostname.format'] = 'Ange ett giltigt fullt kvalificerat domännamn (t.ex. host.domain.com) för värdnamnet.';
$lang['Solusvm.!error.api.internal'] = 'Ett internt fel uppstod, eller så svarade inte servern på begäran.';
$lang['Solusvm.!error.meta[total_base_ip_addresses].format'] = 'Ange endast siffror för IP-adressen, med ett värde på 1 eller mer.';
$lang['Solusvm.!error.meta[template].empty'] = 'Vänligen välj en mall.';
$lang['Solusvm.!error.meta[set_template].format'] = 'Ange om en mall ska väljas eller om kunden själv ska få ange en mall.';
$lang['Solusvm.!error.meta[plan].empty'] = 'Vänligen välj en plan.';
$lang['Solusvm.!error.meta[nodes].empty'] = 'Välj minst en nod eller nodgrupp.';
$lang['Solusvm.!error.meta[type].valid'] = 'Välj en giltig virtualiseringstyp.';
$lang['Solusvm.!error.port.format'] = 'Ange ett giltigt portnummer.';
$lang['Solusvm.!error.host.format'] = 'Värdnamnet verkar vara ogiltigt.';
$lang['Solusvm.!error.key.empty'] = 'Vänligen ange en nyckel.';
$lang['Solusvm.!error.user_id.empty'] = 'Ange ett användar-ID.';
$lang['Solusvm.!error.server_name.empty'] = 'Vänligen ange en serveretikett.';
$lang['SolusVM.!error.simplexml_required'] = 'Tillägget simplexml krävs för denna modul.';
$lang['Solusvm.!actions.password'] = 'Ändra lösenord';
$lang['Solusvm.!actions.hostname'] = 'Ändra värdnamn';
$lang['Solusvm.!actions.reinstall'] = 'Installera om';
$lang['Solusvm.!actions.shutdown'] = 'Avstängning';
$lang['Solusvm.!actions.reboot'] = 'Omstart';
$lang['Solusvm.!actions.boot'] = 'Boot';
